# -*- coding: utf-8 -*-
# Generated by Django 1.10.4 on 2017-01-12 18:33
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('translation_server', '0003_auto_20161021_1303'),
    ]

    operations = [
        migrations.RenameField(
            model_name='translation',
            old_name='created_at',
            new_name='created',
        ),
        migrations.RenameField(
            model_name='translation',
            old_name='updated_at',
            new_name='updated',
        ),
        migrations.RenameField(
            model_name='translationtype',
            old_name='created_at',
            new_name='created',
        ),
        migrations.RenameField(
            model_name='translationtype',
            old_name='updated_at',
            new_name='updated',
        ),
    ]
